==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicToolBarUI__24DragWindow.h <==
// public class javax.swing.plaf.basic.BasicToolBarUI$DragWindow

// class file dependencies
// @dep_class d547e55bb64f2ca8 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 184d12f43c3697c9 java_awt_Window
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ee05c0c16ad21b85 javax_swing_plaf_basic_BasicToolBarUI__24DragWindow

// header file dependencies
// @dep_header java_awt_Window

#include "java/awt/Window.h"

#ifndef _JC_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow_H_
#define _JC_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Insets$object;
struct _jc_java_awt_Point$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicToolBarUI$object;
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__241$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$sub_refs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$refs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$nonrefs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$object	_jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$vmethods	_jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$vtable	_jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$vtype	_jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$method$_init$bf41621710f83cec(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$object *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI$object *);
extern void _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$method$_init$36017f082c83d63f(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$object *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI$object *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__241$object *);

// Virtual methods
extern struct _jc_java_awt_Color$object *_jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$method$getBorderColor$a98e3ae1aeed320b(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$object *);
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$method$getInsets$791f9e6330bba82d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$object *);
extern struct _jc_java_awt_Point$object *_jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$method$getOffset$995691269cbdbf10(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$object *);
extern void _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$method$paint$76f038a09cf0c480(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$object *, struct _jc_java_awt_Graphics$object *);
extern void _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$method$setBorderColor$c1032bbfdac80d2f(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$object *, struct _jc_java_awt_Color$object *);
extern void _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$method$setOffset$9a857cce2c1b5d50(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$object *, struct _jc_java_awt_Point$object *);
extern void _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$method$setOrientation$48158f5aad81cafb(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$method_info$getBorderColor$a98e3ae1aeed320b;
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$method_info$getInsets$791f9e6330bba82d;
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$method_info$getOffset$995691269cbdbf10;
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$method_info$paint$76f038a09cf0c480;
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$method_info$setBorderColor$c1032bbfdac80d2f;
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$method_info$setOffset$9a857cce2c1b5d50;
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$method_info$setOrientation$48158f5aad81cafb;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$vmethods {
	struct _jc_java_awt_Color$object	*(*getBorderColor$a98e3ae1aeed320b)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$object *);
	struct _jc_java_awt_Insets$object	*(*getInsets$791f9e6330bba82d)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$object *);
	struct _jc_java_awt_Point$object	*(*getOffset$995691269cbdbf10)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$object *);
	void	(*paint$76f038a09cf0c480)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$object *, struct _jc_java_awt_Graphics$object *);
	void	(*setBorderColor$c1032bbfdac80d2f)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$object *, struct _jc_java_awt_Color$object *);
	void	(*setOffset$9a857cce2c1b5d50)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$object *, struct _jc_java_awt_Point$object *);
	void	(*setOrientation$48158f5aad81cafb)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$object *, jint);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_java_awt_Window$vmethods	java_awt_Window;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$vmethods	javax_swing_plaf_basic_BasicToolBarUI__24DragWindow;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$sub_refs {
	struct _jc_java_awt_Color$object	*borderColor;
	struct _jc_java_awt_Point$object	*offset;
	struct _jc_javax_swing_plaf_basic_BasicToolBarUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$refs {
    _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$sub_refs	javax_swing_plaf_basic_BasicToolBarUI__24DragWindow;
    _jc_java_awt_Window$sub_refs	java_awt_Window;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_java_awt_Window$sub_nonrefs	java_awt_Window;
    _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$sub_nonrefs	javax_swing_plaf_basic_BasicToolBarUI__24DragWindow;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$object {
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$vtype _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicToolBarUI__24DragWindow, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicToolBarUI__24DragWindow.h <==
// public class javax.swing.plaf.basic.BasicToolBarUI$DragWindow

// class file dependencies
// @dep_class 5a2bf6e9db456f42 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class fd4ae025aa56ceb9 java_awt_Window
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7b307571eac35ee5 javax_swing_plaf_basic_BasicToolBarUI__24DragWindow

// header file dependencies
// @dep_header java_awt_Window

#include "java/awt/Window.h"

#ifndef _JC_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow_H_
#define _JC_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Insets$object;
struct _jc_java_awt_Point$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicToolBarUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$sub_refs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$refs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$nonrefs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$object	_jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$vmethods	_jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$vtable	_jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$vtype	_jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$method$_init$bf41621710f83cec(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$object *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_Color$object *_jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$method$getBorderColor$a98e3ae1aeed320b(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$method$getInsets$791f9e6330bba82d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Point$object *_jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$method$getOffset$995691269cbdbf10(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$method$paint$76f038a09cf0c480(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$object *, struct _jc_java_awt_Graphics$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$method$setBorderColor$c1032bbfdac80d2f(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$object *, struct _jc_java_awt_Color$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$method$setOffset$9a857cce2c1b5d50(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$object *, struct _jc_java_awt_Point$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$method$setOrientation$48158f5aad81cafb(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$method_info$getBorderColor$a98e3ae1aeed320b;
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$method_info$getInsets$791f9e6330bba82d;
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$method_info$getOffset$995691269cbdbf10;
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$method_info$paint$76f038a09cf0c480;
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$method_info$setBorderColor$c1032bbfdac80d2f;
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$method_info$setOffset$9a857cce2c1b5d50;
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$method_info$setOrientation$48158f5aad81cafb;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$vmethods {
	struct _jc_java_awt_Color$object	*(*getBorderColor$a98e3ae1aeed320b)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Insets$object	*(*getInsets$791f9e6330bba82d)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Point$object	*(*getOffset$995691269cbdbf10)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$object *) _JC_JCNI_ATTR;
	void	(*paint$76f038a09cf0c480)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$object *, struct _jc_java_awt_Graphics$object *) _JC_JCNI_ATTR;
	void	(*setBorderColor$c1032bbfdac80d2f)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$object *, struct _jc_java_awt_Color$object *) _JC_JCNI_ATTR;
	void	(*setOffset$9a857cce2c1b5d50)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$object *, struct _jc_java_awt_Point$object *) _JC_JCNI_ATTR;
	void	(*setOrientation$48158f5aad81cafb)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_java_awt_Window$vmethods	java_awt_Window;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$vmethods	javax_swing_plaf_basic_BasicToolBarUI__24DragWindow;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$sub_refs {
	struct _jc_java_awt_Color$object	*borderColor;
	struct _jc_java_awt_Point$object	*offset;
	struct _jc_javax_swing_plaf_basic_BasicToolBarUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$refs {
    _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$sub_refs	javax_swing_plaf_basic_BasicToolBarUI__24DragWindow;
    _jc_java_awt_Window$sub_refs	java_awt_Window;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_java_awt_Window$sub_nonrefs	java_awt_Window;
    _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$sub_nonrefs	javax_swing_plaf_basic_BasicToolBarUI__24DragWindow;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$object {
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$vtype _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicToolBarUI__24DragWindow, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicToolBarUI__24DragWindow_H_ */
